window.onload = init;

function init() {
  new Vue({
    el: "#app",
    data: {
      restaurants: [],
      nom: "",
      cuisine: "",
      pageCourante: 0,
      pagesize: 10,
      nbRestaurants: 0,
      nbPagesTotal: 0,
      nomRecherche: "",
      message: ""
    },
    mounted() {
      // appelée automatiquement avant
      // l'affichage
      this.getRestaurantsDuServeur();
    },
    methods: {
      getRestaurantsDuServeur() {
        // on va chercher les restaurants
        let url =
          "http://localhost:8080/api/restaurants?page=" +
          this.pageCourante +
          "&pagesize=" +
          this.pagesize +
          "&name=" +
          this.nomRecherche;
        fetch(url)
          .then(response => {
            return response.json();
          })
          .then(responseJS => {
            console.log(responseJS.msg);
            this.restaurants = responseJS.data;
            this.nbRestaurants = responseJS.count;
            this.nbPagesTotal = Math.ceil(this.nbRestaurants / this.pagesize);
          });
      },
      supprimerRestaurant: function(id) {
        // on le rajoute côté serveur
        let url = "http://localhost:8080/api/restaurants/" + id;
        fetch(url, {
          method: "DELETE"
        })
          .then(response => {
            return response.json();
          })
          .then(responseJS => {
            this.message = "Restaurant avec id = " + id + " supprimé";
            this.getRestaurantsDuServeur();
          });
      },
      ajouterRestaurant: function() {
        // pour les données du formulaire
        let data = new FormData();
        data.append("nom", this.nom);
        data.append("cuisine", this.cuisine);

        // on le rajoute côté serveur
        let url = "http://localhost:8080/api/restaurants";
        fetch(url, {
          method: "POST",
          body: data
        })
          .then(response => {
            return response.json();
          })
          .then(responseJS => {
            console.log(responseJS.msg);
            this.message = "Restaurant inséré avec id = " + responseJS.result;

            // effacer message au bout de 1s
            setTimeout(() => {
              this.message = "";
            }, 1000);

            this.getRestaurantsDuServeur();
          });

        // on remet le formulaire à zéro
        this.nom = "";
        this.cuisine = "";
      },
      changePageSize() {
        // pas la peine de modifier pagesize, car
        // binding bi-directionnel entre la vue (le slider)
        // et la variable dans data...

        // on a juste besoin de réafficher les restaurants
        this.getRestaurantsDuServeur();
      },
      filtrerParNom() {
        // pas la peine de modifier name, car
        // binding bi-directionnel entre la vue (le champ de saisie)
        // et la variable dans data...

        // on a juste besoin de réafficher les restaurants
        this.getRestaurantsDuServeur();
      },
      pageSuivante() {
        this.pageCourante++;
        this.getRestaurantsDuServeur();
      },
      pagePrecedente() {
        this.pageCourante--;
        this.getRestaurantsDuServeur();
      }
    }
  });
}
